summaryrefslogtreecommitdiff
path: root/src/reel_stereo_picture_asset.h
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2023-11-08 23:55:26 +0100
committerCarl Hetherington <cth@carlh.net>2024-04-18 12:11:42 +0200
commitddb999544ab9da2a3a4760baf241a5ef8520c37e (patch)
tree641253a653aada191f9660f330a81ab79e598009 /src/reel_stereo_picture_asset.h
parentf6d466eee4f1381a65da4b5f6d60924e6a81df4e (diff)
Rename classes.
sed -i "s/\<PictureAsset/J2KPictureAsset/g" src/*.{cc,h} sed -i "s/\<dcp::PictureAsset/dcp::J2KPictureAsset/g" src/*.{cc,h} test/*.{cc,h} tools/*.cc examples/*.cc sed -i "s/\<MonoPictureAsset/MonoJ2KPictureAsset/g" src/*.{cc,h} tools/*.cc test/*.{cc,h} sed -i "s/\<dcp::MonoPictureAsset/dcp::MonoJ2KPictureAsset/g" src/*.{cc,h} test/*.{cc,h} tools/*.cc examples/*.cc sed -i "s/\<StereoPictureAsset/StereoJ2KPictureAsset/g" src/*.{cc,h} tools/*.cc sed -i "s/\<dcp::StereoPictureAsset/dcp::StereoJ2KPictureAsset/g" src/*.{cc,h} test/*.{cc,h} tools/*.cc examples/*.cc sed -i "s/\<MonoPictureFrame/MonoJ2KPictureFrame/g" src/*.{cc,h} tools/*.cc test/*.{cc,h} sed -i "s/\<dcp::MonoPictureFrame/dcp::MonoJ2KPictureFrame/g" src/*.{cc,h} test/*.{cc,h} tools/*.cc examples/*.cc sed -i "s/\<StereoPictureFrame/StereoJ2KPictureFrame/g" src/*.{cc,h} tools/*.cc sed -i "s/\<dcp::StereoPictureFrame/dcp::StereoJ2KPictureFrame/g" src/*.{cc,h} test/*.{cc,h} tools/*.cc examples/*.cc
Diffstat (limited to 'src/reel_stereo_picture_asset.h')
-rw-r--r--src/reel_stereo_picture_asset.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/reel_stereo_picture_asset.h b/src/reel_stereo_picture_asset.h
index 7a836164..09170ddd 100644
--- a/src/reel_stereo_picture_asset.h
+++ b/src/reel_stereo_picture_asset.h
@@ -48,7 +48,7 @@
namespace dcp {
-class StereoPictureAsset;
+class StereoJ2KPictureAsset;
/** @class ReelStereoPictureAsset
@@ -57,17 +57,17 @@ class StereoPictureAsset;
class ReelStereoPictureAsset : public ReelPictureAsset
{
public:
- ReelStereoPictureAsset (std::shared_ptr<StereoPictureAsset> content, int64_t entry_point);
+ ReelStereoPictureAsset (std::shared_ptr<StereoJ2KPictureAsset> content, int64_t entry_point);
explicit ReelStereoPictureAsset (std::shared_ptr<const cxml::Node>);
- /** @return the StereoPictureAsset that this object refers to */
- std::shared_ptr<const StereoPictureAsset> stereo_asset () const {
- return asset_of_type<const StereoPictureAsset>();
+ /** @return the StereoJ2KPictureAsset that this object refers to */
+ std::shared_ptr<const StereoJ2KPictureAsset> stereo_asset () const {
+ return asset_of_type<const StereoJ2KPictureAsset>();
}
- /** @return the StereoPictureAsset that this object refers to */
- std::shared_ptr<StereoPictureAsset> stereo_asset () {
- return asset_of_type<StereoPictureAsset>();
+ /** @return the StereoJ2KPictureAsset that this object refers to */
+ std::shared_ptr<StereoJ2KPictureAsset> stereo_asset () {
+ return asset_of_type<StereoJ2KPictureAsset>();
}
private: